@@ -16,9 +16,12 @@
 
 hyperoverlap_pairs_plot <-  function(x, cols = pal){
 
+  #global variable binding
+  result <- NULL
+
   entity1 <- entity2 <- NULL
   pal = c("red","blue","lightgrey")
-  overlap.plot = ggplot2::ggplot(data = x, aes(entity1, entity2, fill = as.factor(x$result)))+
+  overlap.plot = ggplot2::ggplot(data = x, aes(entity1, entity2, fill = as.factor(result)))+
                  geom_tile(color = "white", na.rm=TRUE, lwd=3)+
                  theme_void()+
                  scale_fill_manual(values=cols)+
